@echo on
set "SystemDrive=C:"
set "LIBRARY_BIN=C:\ci\pymongo_1561563782991\_h_env\Library\bin"
set "PIP_NO_BUILD_ISOLATION=False"
set "PATHEXT=.COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC"
set "CommonProgramFiles(x86)=C:\Program Files (x86)\Common Files"
set "fontconfig=2.13"
set "CONDA_R=3.5"
set "LIBRARY_LIB=C:\ci\pymongo_1561563782991\_h_env\Library\lib"
set "tk=8.6"
set "cran_mirror=https://mran.microsoft.com/snapshot/2018-01-01"
set "freetype=2.9"
set "HOMEPATH=\Users\builder"
set "PY3K=0"
set "CYGWIN_PREFIX=/cygdrive/c/ci/pymongo_1561563782991/_h_env"
set "HOMEDRIVE=C:"
set "ctng_kernel=2.6.32"
set "CONDA_BUILD_SYSROOT=/opt/MacOSX10.10.sdk"
set "PKG_HASH=1234567"
set "ctng_mpc=1"
set "PIP_NO_INDEX=True"
set "libwebp=1.0.0"
set "libxslt=1.1"
set "NUMBER_OF_PROCESSORS=6"
set "macos_machine=x86_64-apple-darwin13.4.0"
set "ctng_libc=gnu"
set "PYTHONNOUSERSITE=1"
set "libpng=1.6"
set "libgd=2.2.5"
set "boost=1.67"
set "NPY_VER=1.11"
set "hdf4=4.2"
set "hdf5=1.10.4"
set "PIP_CACHE_DIR=C:\ci\pymongo_1561563782991\pip_cache"
set "extend_keys=set(['pin_run_as_build', 'ignore_build_only_deps', 'extend_keys', 'ignore_version'])"
set "TMP=C:\Users\builder\AppData\Local\Temp"
set "COMPUTERNAME=WIN10WORKER-07"
set "USERDOMAIN=WIN10WORKER-07"
set "apr=1.6.3"
set "cxx_compiler=vs2008"
set "BUILD_PREFIX=C:\ci\pymongo_1561563782991\_build_env"
set "libgsasl=1.8"
set "giflib=5.1"
set "SP_DIR=C:\ci\pymongo_1561563782991\_h_env\Lib\site-packages"
set "STDLIB_DIR=C:\ci\pymongo_1561563782991\_h_env\Lib"
set "ALLUSERSPROFILE=C:\ProgramData"
set "ctng_gmp=6.1.2"
set "CONDA_DEFAULT_ENV=C:\ci\pymongo_1561563782991\_h_env"
set "ProgramFiles(x86)=C:\Program Files (x86)"
set "ProgramW6432=C:\Program Files"
set "USERNAME=builder"
set "pin_run_as_build=OrderedDict([('python', {u'max_pin': u'x.x', u'min_pin': u'x.x'}), ('r-base', {u'max_pin': u'x.x', u'min_pin': u'x.x'}), (u'libboost', {u'max_pin': u'x.x.x'})])"
set "libkml=1.3"
set "macos_min_version=10.9"
set "CONDA_PERL=5.26"
set "PKG_NAME=pymongo"
set "ProgramFiles=C:\Program Files (x86)"
set "target_platform=win-64"
set "r_base=3.5"
set "ComSpec=C:\Windows\system32\cmd.exe"
set "gnu=2.12.2"
set "zlib=1.2"
set "SHLIB_EXT=.dll"
set "CommonProgramFiles=C:\Program Files (x86)\Common Files"
set "cpu_optimization_target=nocona"
set "PUBLIC=C:\Users\Public"
set "USERPROFILE=C:\Users\builder"
set "hdfeos5=5.1"
set "sqlite=3"
set "vc=9"
set "hdfeos2=2.20"
set "nodejs=6.10"
set "PYTHON=C:\ci\pymongo_1561563782991\_h_env\python.exe"
set "libxml2=2.9"
set "ctng_gcc_build_number=2"
set "expat=2.2"
set "PKG_BUILD_STRING=placeholder"
set "PROCESSOR_IDENTIFIER=Intel64 Family 6 Model 62 Stepping 4, GenuineIntel"
set "ctng_isl=0.19"
set "ARCH=64"
set "libdap4=3.19"
set "llvm_variant=llvm"
set "MACOSX_DEPLOYMENT_TARGET=10.9"
set "LOCALAPPDATA=C:\Users\builder\AppData\Local"
set "openblas=0.3.3"
set "ctng_gcc=8.2.0"
set "CONDA_PY=27"
set "r_version=3.5.0"
set "ctng_libiconv=1.15"
set "qtwebkit=true"
set "ctng_nature=shared"
set "NPY_DISTUTILS_APPEND_FLAGS=1"
set "zip_keys=[[u'ctng_gcc', u'ctng_gcc_build_number', u'ctng_gcc_activation_build_num'], [u'vc', u'c_compiler', u'cxx_compiler', u'fortran_compiler_version', u'python', u'nodejs', u'geos']]"
set "libnetcdf=4.6"
set "PSModulePath=C:\Windows\system32\WindowsPowerShell\v1.0\Modules\"
set "jpeg=9"
set "fortran_compiler_version=13.1.6"
set "gmp=6.1"
set "pixman=0.34"
set "libtiff=4.0"
set "CONDA_BUILD_STATE=BUILD"
set "CPU_COUNT=6"
set "BUILD=amd64-pc-windows-15.0.0"
set "lzo=2"
set "openjpeg=2.3"
set "proj4=5.2.0"
set "dbus=1"
set "g2clib=1.6"
set "ctng_gcc_activation_build_num=4"
set "ctng_duma=2.5.15"
set "blas_impl=mkl"
set "SRC_DIR=C:\ci\pymongo_1561563782991\work"
set "ctng_binutils=2.31.1"
set "cairo=1.14"
set "VS2017INSTALLDIR=C:\Program Files (x86)\Microsoft Visual Studio\2017\Professional"
set "clang_variant=clang"
set "TEMP=C:\Users\builder\AppData\Local\Temp"
set "geos=3.6.2"
set "PIP_NO_DEPENDENCIES=True"
set "PERL_VER=5.26"
set "icu=58"
set "LOGONSERVER=\\WIN10WORKER-07"
set "LUA_VER=5"
set "APPDATA=C:\Users\builder\AppData\Roaming"
set "LIBRARY_INC=C:\ci\pymongo_1561563782991\_h_env\Library\include"
set "openssl=1.1.1"
set "LIBRARY_PREFIX=C:\ci\pymongo_1561563782991\_h_env\Library"
set "VERBOSE_CM=VERBOSE=1"
set "libprotobuf=3.6.0"
set "gst_plugins_base=1.14"
set "rust_compiler=rust-gnu"
set "ignore_build_only_deps=set(['python', 'numpy'])"
set "harfbuzz=1.7"
set "VS90COMNTOOLS=C:\Program Files (x86)\Microsoft Visual Studio 9.0\Common7\Tools\"
set "xz=5"
set "R_VER=3.5"
set "ProgramData=C:\ProgramData"
set "mkl=2019"
set "PROCESSOR_ARCHITECTURE=x86"
set "ctng_ncurses=6.1"
set "glib=2.56"
set "PROMPT=(build_env) $P$G"
set "PKG_BUILDNUM=1"
set "RECIPE_DIR=C:\ci\containers\00001g1edpc\tmp\build\80754af9\rsync-recipes\pymongo-3.8.0-cxx_compiler_vs2008-c_compiler_vs2008-python_2.7-on-winbuilder"
set "libgdal=2.3"
set "SystemRoot=C:\Windows"
set "CommonProgramW6432=C:\Program Files\Common Files"
set "VERBOSE_AT=V=1"
set "cyrus_sasl=2.1.26"
set "CONDA_BUILD=1"
set "gstreamer=1.14"
set "serf=1.3.9"
set "ROOT=C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env"
set "PROCESSOR_ARCHITEW6432=AMD64"
set "cross_compiler_target_platform=win-32"
set "CONDA_LUA=5"
set "PREFIX=C:\ci\pymongo_1561563782991\_h_env"
set "PY_VER=2.7"
set "PATH=C:\ci\pymongo_1561563782991\_build_env;C:\ci\pymongo_1561563782991\_build_env\Library\mingw-w64\bin;C:\ci\pymongo_1561563782991\_build_env\Library\usr\bin;;C:\ci\pymongo_1561563782991\_build_env\Library\bin;C:\ci\pymongo_1561563782991\_build_env\Scripts;C:\ci\pymongo_1561563782991\_build_env\Scripts;C:\ci\pymongo_1561563782991\_h_env;C:\ci\pymongo_1561563782991\_h_env\Library\mingw-w64\bin;C:\ci\pymongo_1561563782991\_h_env\Library\usr\bin;;C:\ci\pymongo_1561563782991\_h_env\Library\bin;C:\ci\pymongo_1561563782991\_h_env\Scripts;C:\ci\pymongo_1561563782991\_h_env\Scripts;C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env;C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env\Library\mingw-w64\bin;C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env\Library\usr\bin;C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env\Library\bin;C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env\Scripts;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\intel64_win\mpirt;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\ia32_win\mpirt;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\intel64_win\compiler;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\ia32_win\compiler;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\intel64\mpirt;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\ia32\mpirt;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\intel64\compiler;C:\Program Files (x86)\Common Files\Intel\Shared Libraries\redist\ia32\compiler;C:\Windows\system32;C:\Windows;C:\Windows\System32\Wbem;C:\Windows\System32\WindowsPowerShell\v1.0\;C:\Program Files\OpenSSH\bin;c:\curl\src;c:\git\mingw64\bin;c:\Program Files (x86)\PuTTY\;c:\Program Files\Mercurial\;c://Program Files/Mercurial/;c:\Program Files (x86)\Microsoft SQL Server\90\Tools\binn\;c:\Program Files\7-Zip;%PROGRAMFILES%\7-Zip;C:\Program Files (x86)\Windows Kits\8.1\Windows Performance Toolkit\;C:\Program Files\7-Zip"
set "windir=C:\Windows"
set "bzip2=1.0"
set "PKG_VERSION=3.8.0"
set "c_compiler=vs2008"
set "libffi=3.2"
set "CONDA_NPY=1.11"
set "SYS_PYTHON=C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env\python.exe"
set "PIP_IGNORE_INSTALLED=True"
set "fortran_compiler=intel-fortran"
set "rust_compiler_version=1.34.1"
set "r_implementation=r-base"
set "SUBDIR=win-64"
set "SCRIPTS=C:\ci\pymongo_1561563782991\_h_env\Scripts"
set "SYS_PREFIX=C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env"
set "mpfr=4"
@echo on
set "INCLUDE=C:\ci\pymongo_1561563782991\_h_env\Library\include;%INCLUDE%"
set "LIB=C:\ci\pymongo_1561563782991\_h_env\Library\lib;%LIB%"
call "C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env\Scripts\..\condabin\conda.bat" activate "C:\ci\pymongo_1561563782991\_h_env"
call "C:\ci\containers\00001g1edpc\tmp\build\80754af9\build_env\Scripts\..\condabin\conda.bat" activate --stack "C:\ci\pymongo_1561563782991\_build_env"
